@@ -79,20 +79,6 @@ void cmdline_completion_init()
 
 void cmdline_completion_final()
 {
-    int i;
-    for(i=0; i<vector_size(gCCandidate); i++) {
-        string_delete(vector_item(gCCandidate, i));
-    }
-    vector_delete(gCCandidate);
-    for(i=0; i<vector_size(gCExplanation); i++) {
-        string_delete(vector_item(gCExplanation, i));
-    }
-    vector_delete(gCExplanation);
-    
-    for(i=0; i<vector_size(gEnvirons); i++) {
-        string_delete(vector_item(gEnvirons, i));
-    }
-    vector_delete(gEnvirons);
 }
 
 ///////////////////////////////////////////////////
@@ -100,14 +86,7 @@ void cmdline_completion_final()
 ///////////////////////////////////////////////////
 void cmdline_completion_clear()
 {
-    int i;
-    for(i=0; i<vector_size(gCCandidate); i++) {
-        string_delete(vector_item(gCCandidate, i));
-    }
     vector_clear(gCCandidate);
-    for(i=0; i<vector_size(gCCandidate); i++) {
-        string_delete(vector_item(gCExplanation, i));
-    }
     vector_clear(gCExplanation);
 }
 
@@ -144,7 +123,6 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
             xstrncpy(des, src, des_size);
 #endif
             vector_add(all_candidate2, STRING_NEW(des));
-            FREE(des);
         }
     }
     else {
@@ -278,12 +256,6 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
         }
     }
     cmdline_convert();
-
-    int i;
-    for(i=0; i<vector_size(all_candidate2); i++) {
-        string_delete(vector_item(all_candidate2, i));
-    }
-    vector_delete(all_candidate2);
 }
 
 ///////////////////////////////////////////////////
@@ -363,12 +335,6 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
 
             cmdline_completion(files, editing_file, TRUE);
         }
-
-        int i;
-        for(i=0; i<vector_size(files); i++) {
-            string_delete(vector_item(files, i));
-        }
-        vector_delete(files);
     }
     /// not exist editing_dir ///
     else {
@@ -411,12 +377,6 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
                 vector_sort(files, name_sort);
                 cmdline_completion(files, editing_file, TRUE);
             }
-
-            int i;
-            for(i=0; i<vector_size(files); i++) {
-                string_delete(vector_item(files, i));
-            }
-            vector_delete(files);
         }
     }
 }
@@ -455,11 +415,6 @@ void cmdline_completion_var(char* editing)
         }
 
         cmdline_completion(new_candidate, editing, TRUE);
-
-        for(i=0; i<vector_size(new_candidate); i++) {
-            string_delete(vector_item(new_candidate, i));
-        }
-        vector_delete(new_candidate);
     }
     else if(*editing == '$' && *(editing+1) =='$') {
         vector_obj* new_candidate = VECTOR_NEW(100);
@@ -475,11 +430,6 @@ void cmdline_completion_var(char* editing)
         }
 
         cmdline_completion(new_candidate, editing, TRUE);
-
-        for(i=0; i<vector_size(new_candidate); i++) {
-            string_delete(vector_item(new_candidate, i));
-        }
-        vector_delete(new_candidate);
     }
     else if(*editing == '@' && *(editing+1) !='@') {
         vector_obj* new_candidate = VECTOR_NEW(100);
@@ -495,11 +445,6 @@ void cmdline_completion_var(char* editing)
         }
 
         cmdline_completion(new_candidate, editing, TRUE);
-
-        for(i=0; i<vector_size(new_candidate); i++) {
-            string_delete(vector_item(new_candidate, i));
-        }
-        vector_delete(new_candidate);
     }
     else if(*editing == '@' && *(editing+1) =='@') {
         vector_obj* new_candidate = VECTOR_NEW(100);
@@ -515,11 +460,6 @@ void cmdline_completion_var(char* editing)
         }
 
         cmdline_completion(new_candidate, editing, TRUE);
-
-        for(i=0; i<vector_size(new_candidate); i++) {
-            string_delete(vector_item(new_candidate, i));
-        }
-        vector_delete(new_candidate);
     }
 }
 
@@ -612,10 +552,6 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
             xstrncpy(cmdname, "", kCmdLineMax);
             *editing_position = 0;
-            int i;
-            for(i=0; i<vector_size(*earray); i++) {
-                string_delete(vector_item(*earray, i));
-            }
             vector_clear(*earray);
  
             while(*p && *p == ' ') p++;
@@ -662,13 +598,6 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
     if(strcmp(editing_dir, "") == 0) {
         xstrncpy(editing_file, editing, kCmdLineMax);
     }
-
-    int i;
-    for(i=0; i<vector_size(*earray); i++) {
-        string_delete(vector_item(*earray, i));
-    }
-    vector_delete(*earray);
-
 }
 
 ///////////////////////////////////////////////////
