@@ -135,8 +135,6 @@ static BOOL match_back(int start)
                     r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
                 }
 
-                FREE(p2);
-
                 migemo_release(gMigemo, (unsigned char*) p);
 
                 if(r != ONIG_NORMAL) {
@@ -270,7 +268,6 @@ static BOOL match_next(int start)
                 else {
                     r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
                 }
-                FREE(p2);
                 migemo_release(gMigemo, (unsigned char*) p);
 
                 if(r != ONIG_NORMAL) {
@@ -432,8 +429,6 @@ void isearch_init()
 ///////////////////////////////////////////////////
 void isearch_final()
 {
-    string_delete(gInputFileName);
-
 #if defined(HAVE_MIGEMO_H)
     if(gMigemoCache) {
         onig_end();
@@ -447,7 +442,6 @@ void isearch_final()
 
             it = hash_loop_next(it);
         }
-        hash_delete(gMigemoCache);
     }
 #endif
 }
