@@ -382,7 +382,7 @@ static void main_arg_e(char* send_cmd, int pid)
 
         struct sockaddr_un addr;
         addr.sun_family = AF_UNIX;
-        strcpy(addr.sun_path, soc_name);
+        xstrncpy(addr.sun_path, soc_name, sizeof(addr.sun_path));
         if(connect(soc, (struct sockaddr *)&addr, sizeof(addr)) == 0) {
             write(soc, send_cmd, strlen(send_cmd)+1);
         }
@@ -414,8 +414,6 @@ static void main_arg_e(char* send_cmd, int pid)
             }
             
             printf("%s", string_c_str(str));
-            
-            string_delete(str);
         }
     }
 }
@@ -832,7 +830,7 @@ int main(int argc, char* argv[])
 #endif
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.3.9", 1);
+    setenv("VERSION", "4.4.0", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -889,7 +887,7 @@ int main(int argc, char* argv[])
     for(i=1 ; i<argc; i++){
         // ファイル名
         if(argv[i][0] != '-') {         // オプションじゃなければ
-            strncpy(file_name, argv[i], PATH_MAX);     // ファイル名とみなす
+            xstrncpy(file_name, argv[i], PATH_MAX);     // ファイル名とみなす
         }
         // 引数
         else {
@@ -963,7 +961,7 @@ int main(int argc, char* argv[])
 
                 struct sockaddr_un addr;
                 addr.sun_family = AF_UNIX;
-                strcpy(addr.sun_path, soc_name);
+                xstrncpy(addr.sun_path, soc_name, sizeof(addr.sun_path));
                 if(connect(soc, (struct sockaddr *)&addr
                         , sizeof(addr)) == 0) 
                 {
@@ -1000,7 +998,7 @@ int main(int argc, char* argv[])
 
                     struct sockaddr_un addr;
                     addr.sun_family = AF_UNIX;
-                    strcpy(addr.sun_path, soc_name);
+                    xstrncpy(addr.sun_path, soc_name, sizeof(addr.sun_path));
                     if(connect(soc, (struct sockaddr *)&addr
                             , sizeof(addr)) == 0) 
                     {
@@ -1047,8 +1045,6 @@ int main(int argc, char* argv[])
                     p++;
                 }
             }
-            
-            string_delete(ret);
         }
 
         saphire_final();
@@ -1070,9 +1066,6 @@ int main(int argc, char* argv[])
     cmdline_init();
     menu_init();
     filer_init();
-    mcurses_init(kTKUtf8);
-    kanji_init();
-    saphire_set_signal();
     saphire_init(kATConsoleApp, TRUE, kRSObject, FALSE);
     cmdline_completion_init();
     commands_init();
@@ -1097,7 +1090,7 @@ int main(int argc, char* argv[])
     
     struct sockaddr_un addr;
     addr.sun_family = AF_UNIX;
-    strcpy(addr.sun_path, soc_name);
+    xstrncpy(addr.sun_path, soc_name, sizeof(addr.sun_path));
     if(bind(soc, (struct sockaddr *)&addr, sizeof(addr)) == -1) {
         perror("bind");
         return 1;
@@ -1129,7 +1122,7 @@ int main(int argc, char* argv[])
         if(strcmp(file_name, "") == 0) {
             char cwd[PATH_MAX];
             mygetcwd(cwd, PATH_MAX);
-            strncat(cwd, "/", PATH_MAX);
+            xstrncat(cwd, "/", PATH_MAX);
 
             if(filer_new_dir(cwd, FALSE, ".+") < 0) {
                 fprintf(stderr, "invalid current directory\n");
@@ -1331,8 +1324,6 @@ int main(int argc, char* argv[])
                 int pipe = open(pipe_name, O_WRONLY);
                 write(pipe, string_c_str(str), string_size(str) +1);
                 close(pipe);
-
-                string_delete(str);
             }
         }
 #endif
@@ -1384,7 +1375,6 @@ int main(int argc, char* argv[])
     }
 
     closedir(dir);
-    string_delete(ret);
 
     /// カーシス終わり ///
     mendwin();
