@@ -24,17 +24,13 @@ static sMenuItem* sMenuItem_new(char* name, int key, char* cmd) {
 
 static void sMenuItem_delete(sMenuItem* self)
 {
-    FREE(self->mName);
-    FREE(self->mCmd);
-
-    FREE(self);
 }
 
 sMenu* sMenu_new(char* title)
 {
     sMenu* self = MALLOC(sizeof(sMenu));
 
-    strcpy(self->mTitle, title);
+    xstrncpy(self->mTitle, title, 256);
     self->mScrollTop = 0;
     self->mCursor = 0;
 
@@ -47,13 +43,6 @@ sMenu* sMenu_new(char* title)
 
 void sMenu_delete(sMenu* self)
 {
-    int i;
-    for(i=0; i<vector_size(self->mMenuItems); i++) {
-        sMenuItem_delete(vector_item(self->mMenuItems, i));
-    }
-    vector_delete(self->mMenuItems);
-
-    FREE(self);
 }
 
 sMenu* gActiveMenu = NULL;
@@ -69,12 +58,6 @@ void menu_init()
 
 void menu_final()
 {
-    hash_it* i = hash_loop_begin(gMenu);
-    while(i != NULL) {
-        sMenu_delete(hash_loop_item(i));
-        i = hash_loop_next(i);
-    }
-    hash_delete(gMenu);
 }
 
 ///////////////////////////////////////////////////
@@ -241,7 +224,7 @@ void menu_view(sMenu* self)
             str_cut2(kUtf8, item->mName, maxx-4, buf, 1024);
         }
         else {
-            strncpy(buf, item->mName, 1024);
+            xstrncpy(buf, item->mName, 1024);
         }
         
         if(i == self->mCursor) {
